cis_config: CisRpc Class Reference

cis_config

Public Member Functions | List of all members
CisRpc Class Reference

C++ interface to cisRpc_t functionality. More...

`#include <CisInterface.hpp>`

Inheritance diagram for CisRpc:

## Public Member Functions
| CisRpc (const char *name, const char *outFormat, const char *inFormat)
| Constructor for CisRpc. More...
| CisRpc (cisRpc_t x)
| Empty constructor for inheritance.
void | _destroy_pi ()
| Alias to allow freeing of underlying C struct at the class level.
| ~CisRpc ()
| Destructor for CisRpc. See cis_free in CisInterface.h for details.
cisRpc_t | pi ()
| Return the cisRpc_t structure. More...
int | send (const int nargs,...)
| Format and send a message to an RPC output queue. See rpcSend from CisInterface.h for details. More...
int | recv (const int nargs,...)
| Receive and parse a message from an RPC input queue. See rpcRecv from CisInterface.h for details. More...

## Detailed Description

C++ interface to cisRpc_t functionality.

The CisRpc class is a basic wrapper around the C cisRpc_t structure and associated functions from the CisInterface.h header. It provides the user with C++ style access to basic RPC messaging via IPC queues.

## Constructor & Destructor Documentation

## ◆ CisRpc()

CisRpc::CisRpc | ( | const char * | name,
|  | const char * | outFormat,
|  | const char * | inFormat
| ) |  |
| inline

Constructor for CisRpc.

Parameters

  [in] | name | constant character pointer name of the output queue.
  [in] | outFormat | character pointer to format that should be used for formatting output.
  [in] | inFormat | character pointer to format that should be used for parsing input.

## Member Function Documentation

## ◆ pi()

cisRpc_t CisRpc::pi | ( |  | ) |
| inline

Return the cisRpc_t structure.

Returns
  cisRpc_t structure underlying the class.

## ◆ recv()

int CisRpc::recv | ( | const int | nargs,
|  |  | ...
| ) |  |
| inline

Receive and parse a message from an RPC input queue. See rpcRecv from CisInterface.h for details.

Parameters

  [in] | nargs | int Number of arguments being passed.
  [out] | ... | mixed arguments that should be assigned parameters extracted using the format string. Since these will be assigned, they should be pointers to memory that has already been allocated.

Returns
  integer specifying if the receive was succesful. Values >= 0 indicate success.

## ◆ send()

int CisRpc::send | ( | const int | nargs,
|  |  | ...
| ) |  |
| inline

Format and send a message to an RPC output queue. See rpcSend from CisInterface.h for details.

Parameters

  [in] | nargs | int Number of arguments being passed.
  [in] | ... | arguments for formatting.

Returns
  integer specifying if the send was succesful. Values >= 0 indicate success.

The documentation for this class was generated from the following file:

- /root/cis_interface/cis_interface/cis_interface/interface/CisInterface.hpp